<?php

/**
 * Gift Card Email Functions
 *
 * @package     Gift-Cards-for-Woocommerce
 * @copyright   Copyright (c) 2014, Ryan Pletcher
 *
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class WPR_Giftcard_Email {

	public function sendEmail ( $post ) {

		$blogname 		= wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);
		$subject 		= apply_filters( 'woocommerce_email_subject_gift_card', sprintf( '[%s] %s', $blogname, __( 'اطلاعات کارت هدیه', 'rpgiftcards' ) ), $post->post_title );
		$sendEmail 		= get_bloginfo( 'admin_email' );
		$headers 		= array('Content-Type: text/html; charset=UTF-8');

		ob_start();

		$mailer 		= WC()->mailer();
		$email 			= new WPR_Giftcard_Email();

		echo '<style >';
		wc_get_template( 'emails/email-styles.php' );
		echo '</style>';

	  	$email_heading 	= __( 'کارت هدیه ی جدید از  ', 'rpgiftcards' ) . $blogname;
	  	$email_heading 	= apply_filters( 'rpgc_emailSubject', $email_heading );
	  	$toEmail		= wpr_get_giftcard_to_email( $post->ID );

	  	$theMessage 	= $email->sendGiftcardEmail ( $post->ID );

		$theMessage 	= apply_filters( 'rpgc_emailContents', $theMessage );

	  	echo $mailer->wrap_message( $email_heading, $theMessage );

		$message 		= ob_get_clean();
		$attachment = '';

		$mailer->send( $toEmail, $subject, $message, $headers, $attachment );

	}
 
    public function sendGiftcardEmail ( $giftCard ) {


		$expiry_date = wpr_get_giftcard_expiration( $giftCard );
		$date_format = get_option('date_format');
		ob_start();
		
		?>

		<div class="message">


			<?php _e( 'دوست عزیز', 'rpgiftcards' ); ?> <?php echo wpr_get_giftcard_to( $giftCard ); ?>,<br /><br />
			
			<?php $message = wpr_get_custom_message();
			if( $message == 'default' ) { ?>
				<?php echo wpr_get_giftcard_from( $giftCard ); ?> <?php _e('می توانید انتخاب کنید', 'rpgiftcards' ); ?> <strong><a href="<?php bloginfo( 'url' ); ?>"><?php bloginfo( 'name' ); ?></a></strong> <?php _e( 'این کارت هدیه متعلق به شماست!شما می توانید با آن خرید آنلاین انجام دهید.', 'rpgiftcards' ); ?> <?php bloginfo( 'name' ); ?>. <br />
			<?php } else {
				echo wpr_get_giftcard_from( $giftCard ); ?> <?php _e('انتخاب یک ', 'rpgiftcards' ); ?> <strong><a href="<?php bloginfo( 'url' ); ?>"><?php bloginfo( 'name' ); ?></a></strong> <?php _e( 'این کارت هدیه متعلق به شماست.', 'rpgiftcards' ); ?>. <?php echo $message; ?> <br />
			<?php } ?>

			<h4><?php _e( 'مقدار اعتبار کارت هدیه', 'rpgiftcards' ); ?>: <?php echo woocommerce_price( wpr_get_giftcard_balance( $giftCard ) ); ?></h4>
			<h4><?php _e( 'شماره ی کارت هدیه', 'rpgiftcards' ); ?>: <?php echo get_the_title( $giftCard ); ?></h4>

			<?php
			if ( $expiry_date != "" ) {
				echo __( 'تاریخ انقضا', 'rpgiftcards' ) . ': ' . date_i18n( get_option( 'date_format' ), strtotime( $expiry_date ) );
			}
			?>
		</div>

		<div style="padding-top: 10px; padding-bottom: 10px; border-top: 1px solid #ccc;">
			<?php echo wpr_get_giftcard_note( $giftCard ); ?>
		</div>

		<div style="padding-top: 10px; border-top: 1px solid #ccc;">
		
		<?php $instruction = wpr_get_custom_instructions();
		if( $instruction == 'default' ) { ?>
			<?php _e( 'به راحتی از کارت هدیه ی خود استفاده کنید.', 'rpgiftcards' ); ?>:

			<ol>
				<li><?php _e( 'فروش در', 'rpgiftcards' ); ?> <?php bloginfo( 'name' ); ?></li>
				<li><?php _e( 'انتخاب"پرداخت توسط کارت هدیه"در طول فرآیند خرید', 'rpgiftcards' ); ?></li>
				<li><?php _e( 'وارد کردن شماره کارت', 'rpgiftcards' ); ?></li>
			</ol>
		</div>
		<?php } else {
			echo $instruction;
		}

		$return = ob_get_clean();
		return apply_filters( 'rpgc_email_content_return', $return, $giftCard );

	}
}


